pub struct StringInterner { /* private fields */ }Implementations
Sourceimpl StringInterner
impl StringInterner
pub fn new() -> Self
pub fn with_capacity(string_capacity: usize, estimated_strings: usize) -> Self
pub fn intern(&mut self, s: &str) -> StrId
Sourcepub fn get_optional(&self, s: &str) -> Option<StrId>
pub fn get_optional(&self, s: &str) -> Option<StrId>
Look up a string in the dedup table without inserting.
Returns StrId if the string already exists, None otherwise.
pub fn lookup(&self, id: StrId) -> &str
Sourcepub fn get_hash(&self, id: StrId) -> u64
pub fn get_hash(&self, id: StrId) -> u64
Recompute the hash of an interned string on demand. The per-string hash is no longer stored (M4) — it is cheaply re-derived from the interned bytes with the same hasher, saving 8 bytes per unique string. Used to key the (separate) entity name table.
pub const fn len(&self) -> usize
pub const fn is_empty(&self) -> bool
pub const fn total_bytes(&self) -> usize